@@ -1817,6 +1817,7 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                         "object_list": "List of object entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
                         "keys_list": "List of key entities, provided as a comma separated list of fields, you can provid object_list or keys_list",
                         "tags_manual": "A comma seperated list of tags to be applied to the entities, to purge all manual tags, send an empty string",
+                        "operation": "OPTIONAL: operation mode - 'replace' (default, replaces all manual tags), 'add' (adds tags to existing), 'remove' (removes specified tags)",
                         "update_comment": "OPTIONAL: a comment for the update, comments are added to the audit record, if unset will be defined to: API update",
                     }
                 ],
@@ -1864,6 +1865,11 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
         collection_tags_policies_name = f"kv_trackme_dhm_tags_tenant_{tenant_id}"
         collection_tags_policies = service.kvstore[collection_tags_policies_name]
 
+        # Store original tags_manual input before loop to prevent mutation issues
+        original_tags_manual = tags_manual
+        # Get operation mode (default: "replace" for backward compatibility)
+        operation = resp_dict.get("operation", "replace")
+
         # loop and proceed
         if object_list:
             keys_list = []
@@ -1903,11 +1909,35 @@ class TrackMeHandlerSplkDhmWrite_v2(trackme_rest_handler.RESTHandler):
                 if tags:
                     tags = tags.split(",")
 
-                # update the record with ours manual tags
+                # Get existing tags_manual before updating
+                existing_tags_manual = kvrecord.get("tags_manual", "")
+                existing_tags_manual_list = existing_tags_manual.split(",") if existing_tags_manual else []
+                # Filter out empty strings
+                existing_tags_manual_list = [x for x in existing_tags_manual_list if x]
+
+                # Process tags_manual based on operation using original input (not mutated)
+                original_tags_manual_list = original_tags_manual.split(",") if original_tags_manual else []
+                original_tags_manual_list = [x for x in original_tags_manual_list if x]  # Filter out empty strings
+
+                if operation == "add":
+                    # Merge: combine existing and new tags, deduplicate (lowercase before deduplication for case-insensitive matching)
+                    all_tags = list(set([x.lower() for x in existing_tags_manual_list + original_tags_manual_list if x]))
+                    tags_manual = ",".join(sorted(all_tags))
+                elif operation == "remove":
+                    # Remove: filter out tags to remove
+                    original_tags_manual_list_lower = [x.lower() for x in original_tags_manual_list]
+                    remaining_tags = [x for x in existing_tags_manual_list if x.lower() not in original_tags_manual_list_lower]
+                    tags_manual = ",".join(sorted([x.lower() for x in remaining_tags if x]))
+                else:  # "replace" (default)
+                    # Replace: use new tags as-is (current behavior)
+                    tags_manual = original_tags_manual  # Use original input
+
+                # update the record with our manual tags
                 kvrecord["tags_manual"] = tags_manual
 
-                # make tags_manual_list (list from tags_manual CSV)
-                tags_manual_list = tags_manual.split(",")
+                # make tags_manual_list (list from tags_manual CSV) for merging with tags_auto
+                tags_manual_list = tags_manual.split(",") if tags_manual else []
+                tags_manual_list = [x for x in tags_manual_list if x]  # Filter out empty strings
 
                 # merged them all: define the tags field as the deduplicated, lowercase and sorted list of tags based on the tags_auto and tags_manual_list
                 tags = ",".join(
